; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;****************************************************************************
begin
;****************************************************************************
; SST data
;****************************************************************************
  filename1 = "fig3.sst.bin"

  nt = 2  ; trend & significance
  ey = 89 
  ex = 180 

  obs_sst = new((/nt,ey,ex/), "float")
  gcm_sst = new((/nt,ey,ex/), "float")

  dims_sst = (/ey,ex/)

  obs_sst(0,:,:) = fbindirread(filename1, 0, dims_sst, "float")  ;obs
  obs_sst(1,:,:) = fbindirread(filename1, 1, dims_sst, "float")  

  gcm_sst(0,:,:) = fbindirread(filename1, 2, dims_sst, "float")  ;multi-model mean of the ensmeble-mean trends
  gcm_sst(1,:,:) = fbindirread(filename1, 3, dims_sst, "float")  

  obs_sst!0="time"
  obs_sst!1="lat"
  obs_sst!2="lon"

  obs_sst&lat = fspan(-88,88,ey)
  obs_sst&lon = fspan(0,358,ex)
  obs_sst&lat@units = "degrees_north"
  obs_sst&lon@units = "degrees_east"

  obs_sst@_FillValue = -999.99
  gcm_sst@_FillValue = -999.99

  copy_VarCoords(obs_sst,gcm_sst)

;****************************************************************************
; SIC data
;****************************************************************************
  filename2 = "fig3.sic.bin"

  ny = 180 
  nx = 360 

  obs_sic = new((/nt,ny,nx/), "float")    
  gcm_sic = new((/nt,ny,nx/), "float")    

  dims_sic = (/ny,nx/)

  obs_sic(0,:,:) = fbindirread(filename2, 0, dims_sic, "float") ; obs
  obs_sic(1,:,:) = fbindirread(filename2, 1, dims_sic, "float")

  gcm_sic(0,:,:) = fbindirread(filename2, 2, dims_sic, "float") ; multi-model mean of the ensemble-mean trends 
  gcm_sic(1,:,:) = fbindirread(filename2, 3, dims_sic, "float")

  obs_sic!0="time"
  obs_sic!1="lat"
  obs_sic!2="lon"

  obs_sic&lat = fspan(-89.5,89.5,ny)
  obs_sic&lon = fspan(-179.5,179.5,nx)
  obs_sic&lat@units = "degrees_north"
  obs_sic&lon@units = "degrees_east"

  obs_sic@_FillValue = -999.99
  gcm_sic@_FillValue = -999.99

  copy_VarCoords(obs_sic,gcm_sic)

;*****************************************************************************
  wks = gsn_open_wks("X11","fig3")

  res = True
  res@gsnDraw                      = False 
  res@gsnFrame                     = False 

  res@vpHeightF                    = 0.435 
  res@vpWidthF                     = 0.56 

  res@cnFillOn                     = True  
  res@cnFillPalette                = "BlueDarkRed18"
  res@cnLinesOn                    = False  
  res@cnLineLabelsOn               = False 
  res@gsnLeftString                = "(b) Southern Ocean Temperature" 
  res@gsnRightString               = " "  
  res@gsnLeftStringFontHeightF     = 0.015
  res@mpFillOn                     = False  

  res@cnLevelSelectionMode         = "ExplicitLevels"
  res@cnLevels                     = (/-0.3,-0.25,-0.2,-0.15,-0.1,-0.05,0,0.05,0.1,0.15,0.2,0.25,0.3/) 
  res@mpMaxLatF                    = 60.
  res@mpMinLatF                    = -90.
  res@mpCenterLonF                 = 180.
  res@mpMinLonF                    = 0.
  res@mpMaxLonF                    = 360.
  res@gsnMajorLatSpacing           = 30
  res@gsnMajorLonSpacing           = 60
  res@tmXBMode                     = "Explicit"
  res@tmYLMode                     = "Explicit"
  res@tmXBLabelFontHeightF         = 0.013
  res@tmYLLabelFontHeightF         = 0.013
  res@lbLabelBarOn                 = True 
  res@tmXBMinorOn                  = False
  res@tmYLMinorOn                  = False
  res@tmXTOn                       = False
  res@tmYROn                       = False

  res@tmXBMajorLengthF             = 0.009
  res@tmXBMajorOutwardLengthF      = 0.009
  res@tmYLMajorLengthF             = 0.009
  res@tmYLMajorOutwardLengthF      = 0.009

  res@lbOrientation                = "horizontal"  
  res@pmLabelBarWidthF             = 0.45             
  res@pmLabelBarHeightF            = 0.04
  res@lbLabelFontHeightF           = 0.012
  res@lbTitleOn                    = True 
  res@lbTitleString                = "~S~o~N~C decade~S~-1~N~"
  res@lbTitleFontHeightF           = 0.014
  res@pmLabelBarOrthogonalPosF     = 0.2
  res@lbLabelStride                = 2

;*******************************************************************
  vpres = True
  vpres@gsnDraw                    = False  
  vpres@gsnFrame                   = False    

  vpres@vpHeightF                  = 0.28    
  vpres@vpWidthF                   = 0.28

  vpres@mpPerimOn                  = True 
  vpres@cnFillOn                   = True 
  vpres@cnFillPalette              = "BrownBlue12"
  vpres@cnLinesOn                  = False   
  vpres@cnLineLabelsOn             = False   
  vpres@gsnCenterString            = ""
  vpres@gsnRightString             = ""  
  vpres@gsnCenterStringFontHeightF = 0.015
  vpres@gsnLeftStringFontHeightF   = 0.015
  vpres@mpFillOn                   = False
  vpres@cnLevelSelectionMode       = "ExplicitLevels"
  vpres@cnLevels                   = (/-6.,-5.,-4.,-3.,-2.,-1.,0.,1.,2.,3.,4.,5.,6./)
  vpres@mpMaxLatF                  = -50.
  vpres@mpGridAndLimbOn            = True
  vpres@gsnPolarLabelFontHeightF   = 0.013
  vpres@lbLabelBarOn               = True

  vpres@gsnPolar                   = "SH"
  vpres@mpGridLonSpacingF          = 45.
  vpres@mpGridLatSpacingF          = 10.

  vpres@lbOrientation              = "horizontal"
  vpres@pmLabelBarWidthF           = 0.3
  vpres@pmLabelBarHeightF          = 0.04
  vpres@lbLabelFontHeightF         = 0.012
  vpres@lbTitleOn                  = True
  vpres@lbTitleString              = "% decade~S~-1~N~"
  vpres@lbTitleFontHeightF         = 0.014
  vpres@lbLabelStride              = 2
  vpres@pmLabelBarOrthogonalPosF   = 0.05

;*************************************************************************
  tpres = vpres

  tpres@cnFillPalette              = "BlueDarkRed18"
  tpres@cnLevels                   = (/-0.3,-0.25,-0.2,-0.15,-0.1,-0.05,0,0.05,0.1,0.15,0.2,0.25,0.3/)
  tpres@lbTitleString              = "~S~o~N~C decade~S~-1~N~"

;*************************************************************************
  res2=True
  res2@gsnDraw = False
  res2@gsnFrame = False

  res2@cnLevelSelectionMode        = "ManualLevels"
  res2@cnMinLevelValF              = -300.
  res2@cnMaxLevelValF              = 300.
  res2@cnLevelSpacingF             = 10.
  res2@cnInfoLabelOn               = False
  res2@cnLinesOn                   = False
  res2@cnLineLabelsOn              = False
  res2@cnFillScaleF                = 0.5

  res3=res2
  res3@cnMinLevelValF              = 0.
  res3@cnMaxLevelValF              = 100.
  res3@cnLevelSpacingF             = 1.
  res3@cnFillScaleF                = 0.3

;***************************************************************************
  vres = res

  delete(vres@pmLabelBarOrthogonalPosF)

  vres@cnFillPalette               = "BrownBlue12"
  vres@cnFillMode                  = "RasterFill"
  vres@cnLevels                    = (/-6.,-5.,-4.,-3.,-2.,-1.,0.,1.,2.,3.,4.,5.,6./) 
  vres@mpMaxLatF                   = -50.
  vres@gsnMajorLatSpacing          = 20

  vres@lbTitleString               = "% decade~S~-1~N~"
  vres@pmLabelBarOrthogonalPosF    = 0.75

;***************************************************************************
; Panel (a)
;***************************************************************************
  vpres@vpXF                      = 0.042
  vpres@vpYF                      = 0.875

  vpres@gsnLeftString             = "Observed SIC Trend (HadISST)" 
  plotA1 = gsn_csm_contour_map(wks,obs_sic(0,:,:),vpres)
  plotA2 = gsn_csm_contour(wks,obs_sic(1,:,:),res2)

  opt = True
  opt@gsnShadeFillType            = "pattern"
  opt@gsnShadeHigh                = 17
  opt@gsnShadeFillDotSizeF        = 0.002

  plotA2 = gsn_contour_shade(plotA2,-800.,-799.,opt)
  overlay(plotA1,plotA2)

;***************************************************************************
; Panel (b)
;***************************************************************************
  res@vpXF                        = 0.422
  res@vpYF                        = 0.982

  res@gsnLeftString               = "Observed SST Trend (ERSST)" 
  plotC1 = gsn_csm_contour_map(wks,obs_sst(0,:,:),res)
  plotC2 = gsn_csm_contour(wks,obs_sst(1,:,:),res2)
  plotC2 = gsn_contour_shade(plotC2,-800.,-799.,opt)
  overlay(plotC1,plotC2)

;***************************************************************************
; Panel (c)
;***************************************************************************
  vpres@vpXF                      = 0.042
  vpres@vpYF                      = 0.47

  vpres@gsnLeftString             = "Multi-Model Mean SIC Trend"
  plotD1 = gsn_csm_contour_map(wks,gcm_sic(0,:,:),vpres)
  plotD2 = gsn_csm_contour(wks,gcm_sic(1,:,:),res2)
  plotD2 = gsn_contour_shade(plotD2,-800.,-799.,opt)
  overlay(plotD1,plotD2)

;***************************************************************************
; Panel (d)
;***************************************************************************
  res@vpXF                        = 0.422
  res@vpYF                        = 0.577

  res@gsnLeftString               = "Multi-Model Mean SST Trend"
  plotF1 = gsn_csm_contour_map(wks,gcm_sst(0,:,:),res)
  plotF2 = gsn_csm_contour(wks,gcm_sst(1,:,:),res2)
  plotF2 = gsn_contour_shade(plotF2,-800.,-799.,opt)
  overlay(plotF1,plotF2)

;***************************************************************************
  txres = True
  txres@txFontHeightF = 0.018
  txres@txFont = 22

  gsn_text_ndc(wks,"a",0.01,0.92,txres)
  gsn_text_ndc(wks,"b",0.36,0.92,txres)
  gsn_text_ndc(wks,"c",0.01,0.515,txres)
  gsn_text_ndc(wks,"d",0.36,0.515,txres)

;***************************************************************************
  resP = True  

  maximize_output(wks,resP)
end
