; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"
; load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/contributed.ncl"
;*****************************************************************************
begin
;*****************************************************************************
; observations
;*****************************************************************************
  filename1 = "fig4.obs.bin"

  ny = 89 
  nx = 180 

  obs_cc = new((/ny,nx/), "float")  
  obs_cc_sig = new((/ny,nx/), "float")  
  obs_congruent = new((/ny,nx/), "float")  

  dims = (/ny,nx/)
  obs_cc(:,:) = fbindirread(filename1, 0, dims, "float")
  obs_cc_sig(:,:) = fbindirread(filename1, 1, dims, "float")
  obs_congruent(:,:) = fbindirread(filename1, 2, dims, "float")

  obs_cc!0="lat"
  obs_cc!1="lon"

  obs_cc&lat = fspan(-88.,88.,ny)
  obs_cc&lon = fspan(0.,358.,nx)
  obs_cc&lat@units = "degrees_north"
  obs_cc&lon@units = "degrees_east"

  obs_cc@_FillValue = -999.99
  obs_cc_sig@_FillValue = -999.99
  obs_congruent@_FillValue = -999.99

  copy_VarCoords(obs_cc,obs_cc_sig)
  copy_VarCoords(obs_cc,obs_congruent)

;*****************************************************************************
; gcm
;*****************************************************************************
  filename2 = "fig4.gcm.bin"

  ey = 180
  ex = 360

  gcm_avg = new((/ey,ex/), "float")
  gcm_sig = new((/ey,ex/), "float")

  dims_gcm = (/ey,ex/)

  gcm_avg(:,:) = fbindirread(filename2, 0, dims_gcm, "float") 
  gcm_sig(:,:) = fbindirread(filename2, 1, dims_gcm, "float")

  gcm_avg!0="lat"
  gcm_avg!1="lon"

  gcm_avg&lat = fspan(-89.5,89.5,ey)
  gcm_avg&lon = fspan(0.5,359.5,ex)
  gcm_avg&lat@units = "degrees_north"
  gcm_avg&lon@units = "degrees_east"

  gcm_avg@_FillValue = -999.99
  gcm_sig@_FillValue = -999.99

  copy_VarCoords(gcm_avg,gcm_sig)

;*****************************************************************************
; time series
;*****************************************************************************
  nmon = 71
  ncol = 8 

  dummy = asciiread("fig4.timeseries.txt",(/nmon,ncol/),"float") 
  dummy@_FillValue = -999.990

  temp = new( (/7,nmon/),typeof(dummy),dummy@_FillValue)

  x = dummy(:,0)

  do icase=0,ncol-2
     temp(icase,:)=dummy(:,icase+1)
  end do

  temp(5,:)=temp(5,:) * 0.5

;***************************************************************************
  wks = gsn_open_wks("X11","fig4")

  res = True
  res@gsnDraw = False    
  res@gsnFrame = False   

  res@vpHeightF                 = 0.3 
  res@vpWidthF                  = 0.4 

  res@cnFillOn                  = True 
  res@cnFillPalette             = "BlueDarkRed18"
  res@cnLinesOn                 = False 
  res@cnLineLabelsOn            = False 
  res@gsnLeftString             = "Correlation of local SST with SO-mean SST"
  res@gsnRightString            = " "       
  res@gsnLeftStringFontHeightF  = 0.013
  res@mpFillOn                  = False    
  res@cnLevelSelectionMode      = "ExplicitLevels"
  res@cnLevels                  = (/-0.6,-0.5,-0.4,-0.3,-0.2,-0.1,0.,0.1,0.2,0.3,0.4,0.5,0.6/)
  res@mpMaxLatF                 = 60.
  res@mpMinLatF                 = -90.
  res@mpCenterLonF              = 180.
  res@mpMinLonF                 = 0.
  res@mpMaxLonF                 = 360.
  res@gsnMajorLatSpacing        = 30
  res@gsnMajorLonSpacing        = 60
  res@tmXBMode                  = "Explicit"
  res@tmYLMode                  = "Explicit"
  res@tmXBLabelFontHeightF      = 0.012
  res@tmYLLabelFontHeightF      = 0.012
  res@lbLabelBarOn              = True
  res@tmXBMinorOn               = False
  res@tmYLMinorOn               = False
  res@tmXTOn                    = False
  res@tmYROn                    = False

  res@tmXBMajorLengthF          = 0.009
  res@tmXBMajorOutwardLengthF   = 0.009
  res@tmYLMajorLengthF          = 0.009
  res@tmYLMajorOutwardLengthF   = 0.009

  res@lbOrientation             = "horizontal"  
  res@pmLabelBarWidthF          = 0.38         
  res@pmLabelBarHeightF         = 0.03
  res@lbLabelFontHeightF        = 0.012
  res@lbTitleOn                 = True 
  res@lbTitleString             = " "
  res@lbTitleFontHeightF        = 0.013
  res@pmLabelBarOrthogonalPosF  = 0.27
  res@lbLabelStride             = 2

;****************************************************************************
  res2=True
  res2@gsnDraw = False
  res2@gsnFrame = False

  res2@cnLevelSelectionMode     = "ManualLevels"
  res2@cnMinLevelValF           = -300.
  res2@cnMaxLevelValF           = 300.
  res2@cnLevelSpacingF          = 10.
  res2@cnInfoLabelOn            = False
  res2@cnLinesOn                = False
  res2@cnLineLabelsOn           = False
  res2@cnFillScaleF             = 0.5

  res3 = res2
  res3@cnMinLevelValF           = 0.
  res3@cnMaxLevelValF           = 100.
  res3@cnLevelSpacingF          = 1.
  res3@cnFillScaleF             = 0.3

;****************************************************************************
  vres = True  
  vres@gsnDraw = False
  vres@gsnFrame = False

  vres@vpXF                     = 0.1
  vres@vpYF                     = 0.9
  vres@vpHeightF                = 0.2            
  vres@vpWidthF                 = 0.4 

  vres@trYMinF                  = -0.3
  vres@trYMaxF                  = 0.45 
  vres@trXMinF                  = 1950.           
  vres@trXMaxF                  = 2020.          

  vres@tmXBMode                 = "Explicit"
  vres@tmXBValues               = (/1950,1960,1970,1980,1990,2000,2010,2020/)
  vres@tmXBLabels               = "" + vres@tmXBValues

  vres@tmYLMode                 = "Explicit"
  vres@tmYLValues               = (/-0.3,-0.15,0,0.15,0.3,0.45/)
  vres@tmYLLabels               = (/"-0.30","-0.15","0","0.15","0.30","0.45"/)

  vres@gsnLeftString            = "Time series over 1950-2020" 
  vres@gsnLeftStringFontHeightF = 0.014

  vres@tiYAxisFontHeightF       = 0.014
  vres@tiXAxisFontHeightF       = 0.014
  vres@tmXBLabelFontHeightF     = 0.012
  vres@tmXTLabelFontHeightF     = 0.012
  vres@tmYLLabelFontHeightF     = 0.012
  vres@tmYRLabelFontHeightF     = 0.012

  vres@tmXTOn                   = "False"
  vres@tmYROn                   = "False"
  vres@tmYRLabelsOn             = "False"
  vres@tmXTLabelsOn             = "False"
  vres@gsnYRefLine              = 0.0
  vres@gsnYRefLineDashPattern   = 1
  vres@gsnYRefLineThicknessF    = 0.5

  vres@xyMarkLineModes          = (/"Lines","Lines","Lines","Lines","Lines","Lines","Lines"/)
  vres@xyMonoLineColor          = False  
  vres@xyLineColors             = (/"red","red","red","red","blue4","green4","purple"/)
  vres@xyLineThicknesses        = (/2,2,2,2,2,2,2,2,2,2,2/)    
  vres@xyDashPatterns           = (/0,2,4,12,0,0,0,0,0,0,0/)  

  vres@tiYAxisString            = "Temperature (~S~o~N~C)"    

  vres@tmXBMajorLengthF         = 0.009
  vres@tmXBMajorOutwardLengthF  = 0.009
  vres@tmYLMajorLengthF         = 0.009
  vres@tmYLMajorOutwardLengthF  = 0.009

  vres@pmLegendDisplayMode      = "Always"
  vres@pmLegendSide             = "Top"
  vres@pmLegendParallelPosF     = 0.805
  vres@pmLegendOrthogonalPosF   = -0.58

  vres@pmLegendWidthF           = 0.075
  vres@pmLegendHeightF          = 0.095
  vres@lgLabelFontHeightF       = 0.0085
  vres@lgOrientation            = "vertical"
  vres@lgPerimOn                = False
  vres@lgItemOrder              = (/6,5,4,3,2,1,0/)

  vres@xyExplicitLegendLabels   = (/"  ERSST","  HadISST","  COBE","  ERA5","  AMV(x-1)","  IPO(x0.5)","  East EqPac"/)

;*****************************************************************************
; panel (b)
;*****************************************************************************
  res@vpXF                      = 0.58
  res@vpYF                      = 0.9665

  plotA1 = gsn_csm_contour_map(wks,obs_cc(:,:),res)
  plotA2 = gsn_csm_contour(wks,obs_cc_sig(:,:),res2)

  opt = True
  opt@gsnShadeFillType = "pattern"
  opt@gsnShadeHigh = 17
  opt@gsnShadeFillDotSizeF = 0.002
  plotA2 = gsn_contour_shade(plotA2,-800.,-799.,opt)
  overlay(plotA1,plotA2)

;*****************************************************************************
; panel (c)
;*****************************************************************************
  res@vpXF                      = 0.1
  res@vpYF                      = 0.68

  res@cnLevels                  = (/-0.3,-0.25,-0.2,-0.15,-0.1,-0.05,0.,0.05,0.1,0.15,0.2,0.25,0.3/)
  res@lbTitleString             = "~S~o~N~C decade~S~-1~N~"
  res@gsnLeftString             = "Congruent SST trend (Observation)"

  plotB1 = gsn_csm_contour_map(wks,obs_congruent(:,:),res)

;*****************************************************************************
; panel (d)
;*****************************************************************************
  res@vpXF                      = 0.58
  res@vpYF                      = 0.68

  res@gsnLeftString             = "Congruent SST trend (Multi-model mean)"
  plotC1 = gsn_csm_contour_map(wks,gcm_avg(:,:),res)
  plotC2 = gsn_csm_contour(wks,gcm_sig(:,:),res2)
  plotC2 = gsn_contour_shade(plotC2,-800.,-799.,opt)
  overlay(plotC1,plotC2)

;*****************************************************************************
; panel (a)
;*****************************************************************************
  plotD = gsn_csm_xy (wks,x,temp(0:6,:),vres)  

;******************************************************************************
  txres = True
  txres@txFontHeightF = 0.018
  txres@txFont = 22

  gsn_text_ndc(wks,"a",0.035,0.925,txres)
  gsn_text_ndc(wks,"b",0.515,0.925,txres)
  gsn_text_ndc(wks,"c",0.035,0.64,txres)
  gsn_text_ndc(wks,"d",0.515,0.64,txres)

;******************************************************************************
  resP = True 

  maximize_output(wks,resP)
end
